@@ -4,7 +4,7 @@ import numpy as np
 
 import os, sys
 sys.path.append(os.path.join(os.path.dirname(os.path.realpath(__file__)), os.pardir))
-from base.temps_base import BaseTemps
+from base.temps_base import TempsBase
 
 class BaseFrequence():
     def __init__(self, base_de_temps):
