@@ -7,9 +7,7 @@ import os, sys
 sys.path.append(os.path.join(os.path.dirname(os.path.realpath(__file__)), os.pardir))
 
 from filtres.filtre_base import FiltreBase
-from signaux.signal_gbf import SignalGBF
-from signaux.signal_sysam import SignalSysam
-from sysam.sysam_sp5 import demarrer_sysam
+from signaux.signalll import Signal
 
 class FigureDynamique():
     def __init__(self, filtre):
