@@ -29,6 +29,7 @@ class FiltreBase():
         self.__chercher_nom_valide(nom)
 
     def raz(self):
+        print("raz")
         try:
             del(self.vecteur_f)
         except:
@@ -37,6 +38,10 @@ class FiltreBase():
             del(self.vecteur_p)
         except:
             pass
+        try:
+            del(self.vecteur_H_cplx)
+        except:
+            pass
         try:
             del(self.vecteur_G)
         except:
@@ -91,6 +96,7 @@ class FiltreBase():
         except:
             fmin, fmax = self.liste_fmin_fmax
             self.vecteur_f = np.logspace(np.log10(fmin), np.log10(fmax), self.n_points)
+            print("On calcule vecteur f")
         return self.vecteur_f
 
     def calculer_vecteur_p(self, liste_fmin_fmax, n_points):
@@ -101,6 +107,7 @@ class FiltreBase():
         except:
             self.calculer_vecteur_f(liste_fmin_fmax, n_points)
             self.vecteur_p = 1j*2*np.pi*self.vecteur_f
+            print("On calcule vecteur p")
         return self.vecteur_p
 
     def calculer_vecteur_H_cplx(self, liste_fmin_fmax, n_points):
@@ -112,6 +119,8 @@ class FiltreBase():
             self.calculer_vecteur_p(liste_fmin_fmax, n_points)
             N = len(self.vecteur_p)
             self.vecteur_H_cplx = np.ones(N)
+            print("On calcule vecteur H cplx")
+
             return self.vecteur_H_cplx
     
     def calculer_vecteur_G(self, liste_fmin_fmax, n_points):
@@ -122,6 +131,7 @@ class FiltreBase():
         except:
             self.calculer_vecteur_H_cplx(liste_fmin_fmax, n_points)
             self.vecteur_G = np.abs(self.vecteur_H_cplx)
+            print("On calcule vecteur G")
         return self.vecteur_G
 
     def calculer_vecteur_G_dB(self, liste_fmin_fmax, n_points):
@@ -130,8 +140,9 @@ class FiltreBase():
         try:
             N = len(self.vecteur_G_dB)
         except:
-            self.calculer_vecteur_H_cplx(liste_fmin_fmax, n_points)
-            self.vecteur_G_dB = 20*np.log10(np.abs(self.vecteur_H_cplx))
+            self.calculer_vecteur_G(liste_fmin_fmax, n_points)
+            self.vecteur_G_dB = 20*np.log10(self.vecteur_G)
+            print("On calcule vecteur G dB")
         return self.vecteur_G_dB
 
     def calculer_vecteur_phi(self, liste_fmin_fmax, n_points):
@@ -142,6 +153,8 @@ class FiltreBase():
         except:
             self.calculer_vecteur_H_cplx(liste_fmin_fmax, n_points)
             self.vecteur_phi = calculer_argument(self.vecteur_H_cplx)
+            print("On calcule vecteur phi")
+
         return self.vecteur_phi
 
     def tracer_G_dB(self, liste_fmin_fmax, n_points, affichage = True):
