@@ -11,6 +11,7 @@ except:
     # print(" -> Fonctionnement en mode émulation")
     import acquisition.emulateur_sysam_sp5 as pycan
 
+from signaux.signal_1_base import Signal1Base
 from signaux.signalll import Signal
 
 import base.temps_base
@@ -27,14 +28,14 @@ def acquerir_signaux(*args, **kwargs):
 def demarrer_sysam(*args, **kwargs):
     args = list(args)
     liste_signaux = []
-    test_signal = len(args) > 0 and isinstance(args[0], Signal)
+    test_signal = len(args) > 0 and isinstance(args[0], Signal1Base)
     if not test_signal:
         print("Quels sont les signaux gérés par sysam?")
         return
     s = args[0]
     while test_signal:
-        liste_signaux.append(utb.analyser_args(args, " ", lambda x: isinstance(x, Signal), s)[0])
-        test_signal = len(args) > 0 and isinstance(args[0], Signal)
+        liste_signaux.append(utb.analyser_args(args, " ", lambda x: isinstance(x, Signal1Base), s)[0])
+        test_signal = len(args) > 0 and isinstance(args[0], Signal1Base)
     affichage = utb.analyser_args_kwargs(args, kwargs, "affichage", lambda x: isinstance(x, bool), True)
 
     with SysamSP5(liste_signaux, affichage) as sysam:
@@ -127,4 +128,5 @@ if __name__ == "__main__":
     s5.plot()
     plt.legend()
     plt.show()
+    print(type(s1))
     # SignalGBF.tracer_signaux(sortie2, entree1, entree2, titre = "zoo")
\ No newline at end of file
